@@ -1,7 +1,7 @@
 """Object model and utilities to define generic Entities/Relations schemas.
 
 :copyright:
-  2004-2008 `LOGILAB S.A. <http://www.logilab.fr>`_ (Paris, FRANCE),
+  2004-2010 `LOGILAB S.A. <http://www.logilab.fr>`_ (Paris, FRANCE),
   all rights reserved.
 
 :contact:
@@ -13,13 +13,21 @@
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>`_
 """
 __docformat__ = "restructuredtext en"
-from yams.__pkginfo__ import version as __version__
+
+from datetime import datetime, date, time
 
 # set _ builtin to unicode by default, should be overriden if necessary
 import __builtin__
 __builtin__._ = unicode
 
 from logilab.common.compat import set
+from logilab.common.date import strptime, strptime_time
+from logilab.common import nullobject
+
+from yams.__pkginfo__ import version as __version__
+from yams._exceptions import *
+
+MARKER = nullobject()
 
 BASE_TYPES = set(('String', 'Int', 'Float', 'Boolean', 'Date', 'Decimal',
                   'Time', 'Datetime', 'Interval', 'Password', 'Bytes'))
@@ -27,49 +35,16 @@ BASE_TYPES = set(('String', 'Int', 'Float', 'Boolean', 'Date', 'Decimal',
 # base groups used in permissions
 BASE_GROUPS = set((_('managers'), _('users'), _('guests'), _('owners')))
 
+KEYWORD_MAP = {'Datetime.NOW' : datetime.now,
+               'Datetime.TODAY': datetime.today,
+               'Date.TODAY': date.today}
+DATE_FACTORY_MAP = {
+    'Datetime' : lambda x: ':' in x and strptime(x, '%Y/%m/%d %H:%M') or strptime(x, '%Y/%m/%d'),
+    'Date' : lambda x : strptime(x, '%Y/%m/%d'),
+    'Time' : strptime_time
+    }
 
-from logilab.common import nullobject
-MARKER = nullobject()
-
-
-def use_py_datetime():
-    global DATE_FACTORY_MAP, KEYWORD_MAP
-
-    from datetime import datetime, date, time
-    from time import strptime as time_strptime
-
-    try:
-        strptime = datetime.strptime
-    except AttributeError: # py < 2.5
-        def strptime(value, format):
-            return datetime(*time_strptime(value, format)[:6])
-
-    def strptime_time(value, format='%H:%M'):
-        return time(*time_strptime(value, format)[3:6])
-
-    KEYWORD_MAP = {'Datetime.NOW' : datetime.now,
-                   'Datetime.TODAY': datetime.today,
-                   'Date.TODAY': date.today}
-    DATE_FACTORY_MAP = {
-        'Datetime' : lambda x: ':' in x and strptime(x, '%Y/%m/%d %H:%M') or strptime(x, '%Y/%m/%d'),
-        'Date' : lambda x : strptime(x, '%Y/%m/%d'),
-        'Time' : strptime_time
-        }
-
-try:
-    from mx.DateTime import today, now, DateTimeFrom, DateFrom, TimeFrom
-    KEYWORD_MAP = {'Datetime.NOW' : now,
-                   'Datetime.TODAY' : today,
-                   'Date.TODAY': today}
-    DATE_FACTORY_MAP = {'Datetime' : DateTimeFrom,
-                        'Date' : DateFrom,
-                        'Time' : TimeFrom}
-except ImportError:
-    use_py_datetime()
-
-# work in progress
-from yams._exceptions import *
-from yams.schema import Schema, EntitySchema, RelationSchema
+# work in progress ###
 
 class _RelationRole(int):
     def __eq__(self, other):
