@@ -13,7 +13,7 @@ __docformat__ = "restructuredtext en"
 modname = 'yams'
 
 # release version
-numversion = (0, 28, 0)
+numversion = (0, 28, 1)
 version = '.'.join(str(num) for num in numversion)
 
 # license and copyright
@@ -49,3 +49,7 @@ include_dirs = []
 scripts = ['bin/yams-check', 'bin/yams-view']
 
 pyversions = ['2.4', '2.5']
+
+install_requires = [
+    'logilab-common >= 0.47.0',
+    ]
