@@ -1,7 +1,7 @@
 """Exceptions shared by different ER-Schema modules.
 
 :organization: Logilab
-:copyright: 2004-2008 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2004-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 :license: General Public License version 2 - http://www.gnu.org/licenses/
 """
@@ -9,10 +9,11 @@ __docformat__ = "restructuredtext en"
 
 class SchemaError(Exception):
     """base class for schema exceptions"""
-    
+
     def __str__(self):
         return unicode(self).encode('utf8')
-    
+
+
 class UnknownType(SchemaError):
     """using an unknown entity type"""
 
@@ -21,6 +22,7 @@ class UnknownType(SchemaError):
     def __unicode__(self):
         return self.msg % self.args
 
+
 class BadSchemaDefinition(SchemaError):
     """error in the schema definition
 
@@ -38,20 +40,6 @@ class BadSchemaDefinition(SchemaError):
         else:
             return None
     filename = property(__get_filename)
-    
-    def __get_lineno(self):
-        if len(self.args) > 2:
-            return self.args[1]
-        else:
-            return None
-    lineno = property(__get_lineno)
-    
-    def __get_line(self):
-        if len(self.args) > 3:
-            return self.args[2]
-        else:
-            return None
-    line = property(__get_line)
 
     def __unicode__(self):
         msgs = []
@@ -59,23 +47,10 @@ class BadSchemaDefinition(SchemaError):
         if self.filename is not None:
             msgs.append(self.filename)
             args_offset += 1
-            if self.lineno is not None:
-                msgs.append(" line %s" % self.lineno)
-                args_offset += 1
-                if self.line is not None:
-                    msgs.append(' "%s"' % self.line)
-                    args_offset += 1
             msgs.append(': ')
         msgs.append(' '.join(self.args[args_offset:]))
         return ''.join(msgs)
 
-class ESQLParseError(Exception):
-    """raised when a line can not be parsed (end up by a warning)"""
-
-    msg = '%s: unable to parse %s'
-
-    def __str__(self):
-        return self.msg % self.args
 
 class ValidationError(SchemaError):
     """validation error details the reason(s) why the validation failed
@@ -91,8 +66,10 @@ class ValidationError(SchemaError):
         # set args so ValidationError are serializable through pyro
         SchemaError.__init__(self, entity, explanation)
         self.entity = entity
+        assert isinstance(explanation, dict), \
+            'validation error explanation must be a dict'
         self.errors = explanation
-        
+
     def __unicode__(self):
         if len(self.errors) == 1:
             attr, error = self.errors.items()[0]
