@@ -8,9 +8,9 @@
 
 __docformat__ = "restructuredtext en"
 
-import warnings
 import re
 import decimal
+import operator
 from StringIO import StringIO
 
 import yams
@@ -49,7 +49,7 @@ class UniqueConstraint(BaseConstraint):
         return 'unique'
 
     def check_consistency(self, subjschema, objschema, rdef):
-        if not objschema.is_final():
+        if not objschema.final:
             raise BadSchemaDefinition("unique constraint doesn't apply to non "
                                       "final entity type")
 
@@ -79,7 +79,7 @@ class SizeConstraint(BaseConstraint):
         return res
 
     def check_consistency(self, subjschema, objschema, rdef):
-        if not objschema.is_final():
+        if not objschema.final:
             raise BadSchemaDefinition("size constraint doesn't apply to non "
                                       "final entity type")
         if not objschema in ('String', 'Bytes', 'Password'):
@@ -145,7 +145,7 @@ class RegexpConstraint(BaseConstraint):
         return 'regexp %s' % self.serialize()
 
     def check_consistency(self, subjschema, objschema, rdef):
-        if not objschema.is_final():
+        if not objschema.final:
             raise BadSchemaDefinition("regexp constraint doesn't apply to non "
                                       "final entity type")
         if not objschema in ('String', 'Password'):
@@ -170,6 +170,13 @@ class RegexpConstraint(BaseConstraint):
         return RegexpConstraint(self.regexp, self.flags)
 
 
+OPERATORS = {
+    '<=': operator.le,
+    '<': operator.lt,
+    '>': operator.gt,
+    '>=': operator.ge,
+    }
+
 class BoundConstraint(BaseConstraint):
     """the int/float bound constraint :
 
@@ -178,35 +185,33 @@ class BoundConstraint(BaseConstraint):
     """
     __implements__ = IConstraint
 
-    def __init__(self, operator, bound=None):
-        assert operator in ('<=', '<', '>', '>=')
-        warnings.warn("use IntervalBoundConstraint instead of BoundConstraint",
-                      DeprecationWarning, stacklevel=2)
-        self.operator = operator
-        self.bound = bound
+    def __init__(self, op, boundary=None):
+        assert op in OPERATORS, op
+        self.operator = op
+        self.boundary = boundary
 
     def __str__(self):
         return 'value %s' % self.serialize()
 
     def check_consistency(self, subjschema, objschema, rdef):
-        if not objschema.is_final():
+        if not objschema.final:
             raise BadSchemaDefinition("bound constraint doesn't apply to non "
                                       "final entity type")
 
     def check(self, entity, rtype, value):
         """return true if the value satisfy the constraint, else false"""
-        return eval('%s %s %s' % (value, self.operator, self.bound))
+        boundary = actual_value(self.boundary, entity)
+        return OPERATORS[self.operator](value, boundary)
 
     def serialize(self):
         """simple text serialization"""
-        return u'%s %s' % (self.operator, self.bound)
+        return u'%s %s' % (self.operator, self.boundary)
 
     @classmethod
     def deserialize(cls, value):
         """simple text deserialization"""
-        operator = value.split()[0]
-        bound = ' '.join(value.split()[1:])
-        return cls(operator, bound)
+        op, boundary = value.split(' ', 1)
+        return cls(op, eval(boundary))
 
 
 class IntervalBoundConstraint(BaseConstraint):
@@ -230,7 +235,7 @@ class IntervalBoundConstraint(BaseConstraint):
         return 'value [%s]' % self.serialize()
 
     def check_consistency(self, subjschema, objschema, rdef):
-        if not objschema.is_final():
+        if not objschema.final:
             raise BadSchemaDefinition("interval bound constraint doesn't apply "
                                       "to non final entity type")
 
@@ -298,7 +303,7 @@ class FormatConstraint(StaticVocabularyConstraint):
         pass
 
     def check_consistency(self, subjschema, objschema, rdef):
-        if not objschema.is_final():
+        if not objschema.final:
             raise BadSchemaDefinition("unique constraint doesn't apply to non "
                                       "final entity type")
         if not objschema == 'String':
@@ -315,7 +320,7 @@ class FormatConstraint(StaticVocabularyConstraint):
         """
         return cls()
 
-    def vocabulary(self, entity=None, req=None):
+    def vocabulary(self, **kwargs):
         return self.regular_formats
 
     def __str__(self):
@@ -338,8 +343,6 @@ class MultipleStaticVocabularyConstraint(StaticVocabularyConstraint):
 # special classes to be used w/ constraints accepting values as argument(s):
 # IntervalBoundConstraint
 
-# XXX suppose using datetime, not mx.DateTime (but ok since mx.DateTime will be
-# dropped at some point)
 import datetime # needed for timedelta evaluation
 
 def actual_value(value, entity):
@@ -439,6 +442,7 @@ BASE_CHECKERS = {
     'Date' :     yes,
     'Time' :     yes,
     'Datetime' : yes,
+    'Interval' : yes,
     'String' :   check_string,
     'Int' :      check_int,
     'Float' :    check_float,
